@@ -3,8 +3,9 @@
 #' It may occur that the result of the combination of two basic chance assignments with Dempster's Rule of combination contains a non-zero mass allocated to the empty set. The function \code{nzdsr} normalizes the result of function \code{dsrwon} by dividing the mass value of the non-empty subsets by 1 minus the mass of the empty set. 
 #' @param x A basic chance assignment, i.e. a object of class bcaspec.
 #' @param sparse Put "yes" to use sparse matrix. Default = "no".
+#' @param comm Put "yes" to use commonality function. Default = "no".
 #' @return z The normalized basic chance assignment.
-#' @author Claude Boivin
+#' @author Claude Boivin, Peiyuan Zhu
 #' @references Shafer, G., (1976). A Mathematical Theory of Evidence. Princeton University Press, Princeton, New Jersey, pp. 57-61: Dempster's rule of combination.
 #' @examples 
 #' x1 <- bca(tt= matrix(c(1,0,1,1),nrow = 2, byrow = TRUE), 
@@ -34,24 +35,41 @@
 #' nzdsr(y2)  
 #' @export
 #' 
-nzdsr<-function(x, sparse = "no") {
+nzdsr<-function(x, sparse = "no", comm = "no") {
   #
-  # Local variables: nc, vacuous, w1, w12, mac, MACC, empty, m_empty, tri, ind
+  # Local variables: nc, vacuous, w1, w12, mac, MACC, empty, m_empty, tri, ind, m0, Q
   # Functions calls: nameRows
   #
   ## 1. Checks
   if ( inherits(x, "bcaspec") == FALSE) {
     stop("Input argument not of class bcaspec.")
   }
+  
+  # 1.1 Check commonality function
+  if (comm=="yes" && is.null(x$qq)) {
+    stop("Need input commonality function")
+  }
+  
+  # Normalize commonality function
+  if(!is.null(x$qq) && comm=="yes") {
+    Q <- x$qq
+    m0 <- mobiusInvHQQ(Q,rep(0,x$infovar[2]))
+    if(m0 != 0) {
+      x$qq <- function(X) Q(X) / (1 - m0)
+    }
+  }
+  
   #
   # case of tt matrix missing
-  if (is.null(x$tt) ) {
+  if (is.null(x$tt) && comm=="no") {
     if(sparse=="yes") {
       x$tt <- ttmatrix(x$ssnames, "yes")
     } else {
       x$tt <- ttmatrix(x$ssnames)
     }
   }
+  
+  if (comm == "no") {
   #
   # 3. Assign variables
   w12<-cbind(x$spec[,2], x$tt)
@@ -61,7 +79,7 @@ nzdsr<-function(x, sparse = "no") {
   #
   ## 2023-06-26 test reconstruct sort_order if missing
   if (is.null(x$sort_order)) {
-  x$sort_order<-order(apply(x$tt,1,sum))
+    x$sort_order<-order(apply(x$tt,1,sum))
   }
   # End 2023-06-26 Test
   #
@@ -91,6 +109,12 @@ nzdsr<-function(x, sparse = "no") {
   # spec parameter
   spec <- cbind((1:nrow(tt)), MACC)
   colnames(spec) <- c("specnb", "mass")
+  
+  #
+  # Computation of the conflict indice
+  #
+  con <- 1-(1-x$con)*(1-m_empty)
+  }
   #
   # infovar, varnames, valuenames, inforel parameters
   infovar <- x$infovar
@@ -100,13 +124,13 @@ nzdsr<-function(x, sparse = "no") {
   inforel <- matrix(c(relnb, nrow(infovar)), ncol = 2)
   colnames(inforel) <- c("relnb", "depth") 
   #
-  # Computation of the conflict indice
-  #
-  con <- 1-(1-x$con)*(1-m_empty)
-  #
   # construction of the result
-  z <- list(con = con, tt = tt, spec = spec, infovar = infovar, varnames = varnames, valuenames = valuenames, inforel = inforel)
-  class(z) <- append(class(z), "bcaspec")
+  if (comm=="no") {
+    z <- list(con = con, tt = tt, qq = NULL, spec = spec, infovar = infovar, varnames = varnames, valuenames = valuenames, inforel = inforel)
+    class(z) <- append(class(z), "bcaspec")
+  } else {
+    z <- list(con = 0, tt = NULL, qq = x$qq, spec = NULL, infovar = infovar, varnames = varnames, valuenames = valuenames, inforel = inforel)
+  }
   #
   return(z)
-    }
\ No newline at end of file
+}
\ No newline at end of file
